@@ -144,6 +144,15 @@ esyd() {
     disable_pid)
         [ -c '/dev/syd/sandbox/pid:off' ]
         ;;
+    enabled_walk)
+        [ -c '/dev/syd/sandbox/walk?' ]
+        ;;
+    enable_walk)
+        [ -c '/dev/syd/sandbox/walk:on' ]
+        ;;
+    disable_walk)
+        [ -c '/dev/syd/sandbox/walk:off' ]
+        ;;
     enabled_stat)
         [ -c '/dev/syd/sandbox/stat?' ]
         ;;
@@ -324,14 +333,23 @@ esyd() {
     disable_utime)
         [ -c '/dev/syd/sandbox/utime:off' ]
         ;;
-    enabled_mkdev)
-        [ -c '/dev/syd/sandbox/mkdev?' ]
+    enabled_mkbdev)
+        [ -c '/dev/syd/sandbox/mkbdev?' ]
         ;;
-    enable_mkdev)
-        [ -c '/dev/syd/sandbox/mkdev:on' ]
+    enable_mkbdev)
+        [ -c '/dev/syd/sandbox/mkbdev:on' ]
         ;;
-    disable_mkdev)
-        [ -c '/dev/syd/sandbox/mkdev:off' ]
+    disable_mkbdev)
+        [ -c '/dev/syd/sandbox/mkbdev:off' ]
+        ;;
+    enabled_mkcdev)
+        [ -c '/dev/syd/sandbox/mkcdev?' ]
+        ;;
+    enable_mkcdev)
+        [ -c '/dev/syd/sandbox/mkcdev:on' ]
+        ;;
+    disable_mkcdev)
+        [ -c '/dev/syd/sandbox/mkcdev:off' ]
         ;;
     enabled_mkfifo)
         [ -c '/dev/syd/sandbox/mkfifo?' ]
@@ -375,9 +393,7 @@ esyd() {
             return 1
         fi
         # allow is shorthand for all glob capabilities.
-        for capability in stat read write ioctl create delete rename symlink truncate chdir readdir mkdir rmdir chown chgrp chmod chattr chroot mkdev mkfifo mktemp; do
-            _esyd_path "allow/${capability}" '+' "${@}"
-        done
+        _esyd_path "allow/all" '+' "${@}"
         ;;
     disallow|disallow_path)
         op='-'
@@ -387,9 +403,7 @@ esyd() {
             return 1
         fi
         # disallow is shorthand for all glob capabilities.
-        for capability in stat read write ioctl create delete rename symlink truncate chdir readdir mkdir rmdir chown chgrp chmod chattr chroot mkdev mkfifo mktemp; do
-            _esyd_path "allow/${capability}" "${op}" "${@}"
-        done
+        _esyd_path "allow/all" "${op}" "${@}"
         ;;
     deny|deny_path)
         if [ ${#} -lt 1 ]; then
@@ -397,9 +411,7 @@ esyd() {
             return 1
         fi
         # deny is shorthand for all glob capabilities.
-        for capability in stat read write ioctl create delete rename symlink truncate chdir readdir mkdir rmdir chown chgrp chmod chattr chroot mkdev mkfifo mktemp; do
-            _esyd_path "deny/${capability}" '+' "${@}"
-        done
+        _esyd_path "deny/all" '+' "${@}"
         ;;
     nodeny|nodeny_path)
         op='-'
@@ -409,9 +421,39 @@ esyd() {
             return 1
         fi
         # nodeny is shorthand for all glob capabilities.
-        for capability in stat read write ioctl create delete rename symlink truncate chdir readdir mkdir rmdir chown chgrp chmod chattr chroot mkdev mkfifo mktemp; do
-            _esyd_path "deny/${capability}" "${op}" "${@}"
-        done
+        _esyd_path "deny/all" "${op}" "${@}"
+        ;;
+    allow_walk)
+        if [ ${#} -lt 1 ]; then
+            echo >&2 "esyd: ${cmd} takes at least one extra argument"
+            return 1
+        fi
+        _esyd_path 'allow/walk' '+' "${@}"
+        ;;
+    disallow_walk)
+        op='-'
+        [ x"${1}" = 'x--all' ] && op='^' && shift
+        if [ ${#} -lt 1 ]; then
+            echo >&2 "esyd: ${cmd} takes at least one extra argument"
+            return 1
+        fi
+        _esyd_path 'allow/walk' "${op}" "${@}"
+        ;;
+    deny_walk)
+        if [ ${#} -lt 1 ]; then
+            echo >&2 "esyd: ${cmd} takes at least one extra argument"
+            return 1
+        fi
+        _esyd_path 'deny/walk' '+' "${@}"
+        ;;
+    nodeny_walk)
+        op='-'
+        [ x"${1}" = 'x--all' ] && op='^' && shift
+        if [ ${#} -lt 1 ]; then
+            echo >&2 "esyd: ${cmd} takes at least one extra argument"
+            return 1
+        fi
+        _esyd_path 'deny/walk' "${op}" "${@}"
         ;;
     allow_stat)
         if [ ${#} -lt 1 ]; then
@@ -1053,37 +1095,69 @@ esyd() {
         fi
         _esyd_path 'deny/utime' "${op}" "${@}"
         ;;
-    allow_mkdev)
+    allow_mkbdev)
         if [ ${#} -lt 1 ]; then
             echo >&2 "esyd: ${cmd} takes at least one extra argument"
             return 1
         fi
-        _esyd_path 'allow/mkdev' '+' "${@}"
+        _esyd_path 'allow/mkbdev' '+' "${@}"
         ;;
-    disallow_mkdev)
+    disallow_mkbdev)
         op='-'
         [ x"${1}" = 'x--all' ] && op='^' && shift
         if [ ${#} -lt 1 ]; then
             echo >&2 "esyd: ${cmd} takes at least one extra argument"
             return 1
         fi
-        _esyd_path 'allow/mkdev' "${op}" "${@}"
+        _esyd_path 'allow/mkbdev' "${op}" "${@}"
         ;;
-    deny_mkdev)
+    deny_mkbdev)
         if [ ${#} -lt 1 ]; then
             echo >&2 "esyd: ${cmd} takes at least one extra argument"
             return 1
         fi
-        _esyd_path 'deny/mkdev' '+' "${@}"
+        _esyd_path 'deny/mkbdev' '+' "${@}"
         ;;
-    nodeny_mkdev)
+    nodeny_mkbdev)
         op='-'
         [ x"${1}" = 'x--all' ] && op='^' && shift
         if [ ${#} -lt 1 ]; then
             echo >&2 "esyd: ${cmd} takes at least one extra argument"
             return 1
         fi
-        _esyd_path 'deny/mkdev' "${op}" "${@}"
+        _esyd_path 'deny/mkbdev' "${op}" "${@}"
+        ;;
+    allow_mkcdev)
+        if [ ${#} -lt 1 ]; then
+            echo >&2 "esyd: ${cmd} takes at least one extra argument"
+            return 1
+        fi
+        _esyd_path 'allow/mkcdev' '+' "${@}"
+        ;;
+    disallow_mkcdev)
+        op='-'
+        [ x"${1}" = 'x--all' ] && op='^' && shift
+        if [ ${#} -lt 1 ]; then
+            echo >&2 "esyd: ${cmd} takes at least one extra argument"
+            return 1
+        fi
+        _esyd_path 'allow/mkcdev' "${op}" "${@}"
+        ;;
+    deny_mkcdev)
+        if [ ${#} -lt 1 ]; then
+            echo >&2 "esyd: ${cmd} takes at least one extra argument"
+            return 1
+        fi
+        _esyd_path 'deny/mkcdev' '+' "${@}"
+        ;;
+    nodeny_mkcdev)
+        op='-'
+        [ x"${1}" = 'x--all' ] && op='^' && shift
+        if [ ${#} -lt 1 ]; then
+            echo >&2 "esyd: ${cmd} takes at least one extra argument"
+            return 1
+        fi
+        _esyd_path 'deny/mkcdev' "${op}" "${@}"
         ;;
     allow_mkfifo)
         if [ ${#} -lt 1 ]; then
@@ -1226,7 +1300,7 @@ esyd() {
             echo >&2 "esyd: ${cmd} takes at least one extra argument"
             return 1
         fi
-        for capability in stat read write ioctl create delete rename symlink truncate chdir readdir mkdir rmdir chown chgrp chmod chattr chroot mkdev mkfifo mktemp; do
+        for capability in walk stat read write ioctl create delete rename symlink truncate chdir readdir mkdir rmdir chown chgrp chmod chattr chroot mkbdev mkcdev mkfifo mktemp; do
             _esyd_path "filter/${capability}" '+' "${@}" || return 1
         done
         ;;
@@ -1237,10 +1311,26 @@ esyd() {
             echo >&2 "esyd: ${cmd} takes at least one extra argument"
             return 1
         fi
-        for capability in stat read write ioctl create delete rename symlink truncate chdir readdir mkdir rmdir chown chgrp chmod chattr chroot mkdev mkfifo mktemp; do
+        for capability in walk stat read write ioctl create delete rename symlink truncate chdir readdir mkdir rmdir chown chgrp chmod chattr chroot mkbdev mkcdev mkfifo mktemp; do
             _esyd_path "filter/${capability}" "${op}" "${@}" || return 1
         done
         ;;
+    addfilter_walk)
+        if [ ${#} -lt 1 ]; then
+            echo >&2 "esyd: ${cmd} takes at least one extra argument"
+            return 1
+        fi
+        _esyd_path 'filter/walk' '+' "${@}"
+        ;;
+    rmfilter_walk)
+        op='-'
+        [ x"${1}" = 'x--all' ] && op='^' && shift
+        if  [ ${#} -lt 1 ]; then
+            echo >&2 "esyd: ${cmd} takes at least one extra argument"
+            return 1
+        fi
+        _esyd_path 'filter/walk' "${op}" "${@}"
+        ;;
     addfilter_stat)
         if [ ${#} -lt 1 ]; then
             echo >&2 "esyd: ${cmd} takes at least one extra argument"
@@ -1561,21 +1651,37 @@ esyd() {
         fi
         _esyd_path 'filter/utime' "${op}" "${@}"
         ;;
-    addfilter_mkdev)
+    addfilter_mkbdev)
         if [ ${#} -lt 1 ]; then
             echo >&2 "esyd: ${cmd} takes at least one extra argument"
             return 1
         fi
-        _esyd_path 'filter/mkdev' '+' "${@}"
+        _esyd_path 'filter/mkbdev' '+' "${@}"
         ;;
-    rmfilter_mkdev)
+    rmfilter_mkbdev)
         op='-'
         [ x"${1}" = 'x--all' ] && op='^' && shift
         if  [ ${#} -lt 1 ]; then
             echo >&2 "esyd: ${cmd} takes at least one extra argument"
             return 1
         fi
-        _esyd_path 'filter/mkdev' "${op}" "${@}"
+        _esyd_path 'filter/mkbdev' "${op}" "${@}"
+        ;;
+    addfilter_mkcdev)
+        if [ ${#} -lt 1 ]; then
+            echo >&2 "esyd: ${cmd} takes at least one extra argument"
+            return 1
+        fi
+        _esyd_path 'filter/mkcdev' '+' "${@}"
+        ;;
+    rmfilter_mkcdev)
+        op='-'
+        [ x"${1}" = 'x--all' ] && op='^' && shift
+        if  [ ${#} -lt 1 ]; then
+            echo >&2 "esyd: ${cmd} takes at least one extra argument"
+            return 1
+        fi
+        _esyd_path 'filter/mkcdev' "${op}" "${@}"
         ;;
     addfilter_mkfifo)
         if [ ${#} -lt 1 ]; then
@@ -1678,6 +1784,12 @@ enable_pid
     Enable PID sandboxing
 disable_pid
     Disable PID sandboxing
+enabled_walk
+    Return true if walk sandboxing is enabled
+enable_walk
+    Enable walk sandboxing
+disable_walk
+    Disable walk sandboxing
 enabled_stat
     Return true if stat sandboxing is enabled
 enable_stat
@@ -1798,12 +1910,18 @@ enable_utime
     Enable utime sandboxing
 disable_utime
     Disable utime sandboxing
-enabled_mkdev
-    Return true if mkdev sandboxing is enabled
-enable_mkdev
-    Enable mkdev sandboxing
-disable_mkdev
-    Disable mkdev sandboxing
+enabled_mkbdev
+    Return true if mkbdev sandboxing is enabled
+enable_mkbdev
+    Enable mkbdev sandboxing
+disable_mkbdev
+    Disable mkbdev sandboxing
+enabled_mkcdev
+    Return true if mkcdev sandboxing is enabled
+enable_mkcdev
+    Enable mkcdev sandboxing
+disable_mkcdev
+    Disable mkcdev sandboxing
 enabled_mkfifo
     Return true if mkfifo sandboxing is enabled
 enable_mkfifo
@@ -1836,6 +1954,14 @@ deny, deny_path glob
     Deny the given glob pattern for path sandboxing
 nodeny, nodeny_path [--all] glob
     Removes the given glob pattern from the denylist for path sandboxing
+allow_walk glob
+    Allow the given glob pattern for walk sandboxing
+disallow_walk [--all] glob
+    Removes the given glob pattern from the allowlist for walk sandboxing
+deny_walk glob
+    Deny the given glob pattern for walk sandboxing
+nodeny_walk [--all] glob
+    Removes the given glob pattern from the denylist for walk sandboxing
 allow_stat glob
     Allow the given glob pattern for stat sandboxing
 disallow_stat [--all] glob
@@ -1996,14 +2122,22 @@ deny_utime glob
     Deny the given glob pattern for utime sandboxing
 nodeny_utime [--all] glob
     Removes the given glob pattern from the denylist for utime sandboxing
-allow_mkdev glob
-    Allow the given glob pattern for mkdev sandboxing
-disallow_mkdev [--all] glob
-    Removes the given glob pattern from the allowlist for mkdev sandboxing
-deny_mkdev glob
-    Deny the given glob pattern for mkdev sandboxing
-nodeny_mkdev [--all] glob
-    Removes the given glob pattern from the denylist for mkdev sandboxing
+allow_mkbdev glob
+    Allow the given glob pattern for mkbdev sandboxing
+disallow_mkbdev [--all] glob
+    Removes the given glob pattern from the allowlist for mkbdev sandboxing
+deny_mkbdev glob
+    Deny the given glob pattern for mkbdev sandboxing
+nodeny_mkbdev [--all] glob
+    Removes the given glob pattern from the denylist for mkbdev sandboxing
+allow_mkcdev glob
+    Allow the given glob pattern for mkcdev sandboxing
+disallow_mkcdev [--all] glob
+    Removes the given glob pattern from the allowlist for mkcdev sandboxing
+deny_mkcdev glob
+    Deny the given glob pattern for mkcdev sandboxing
+nodeny_mkcdev [--all] glob
+    Removes the given glob pattern from the denylist for mkcdev sandboxing
 allow_mkfifo glob
     Allow the given glob pattern for mkfifo sandboxing
 disallow_mkfifo [--all] glob
@@ -2035,6 +2169,10 @@ addfilter, addfilter_path glob
     Adds the given glob pattern to the list of access violation filters for path sandboxing
 rmfilter, rmfilter_path [--all] glob
     Removes the given glob pattern from the list of access violation filters for path sandboxing
+addfilter_walk glob
+    Adds the given glob pattern to the list of access violation filters for walk sandboxing
+rmfilter_walk [--all] glob
+    Removes the given glob pattern from the list of access violation filters for walk sandboxing
 addfilter_stat glob
     Adds the given glob pattern to the list of access violation filters for stat sandboxing
 rmfilter_stat [--all] glob
@@ -2115,10 +2253,14 @@ addfilter_utime glob
     Adds the given glob pattern to the list of access violation filters for utime sandboxing
 rmfilter_utime [--all] glob
     Removes the given glob pattern from the list of access violation filters for utime sandboxing
-addfilter_mkdev glob
-    Adds the given glob pattern to the list of access violation filters for mkdev sandboxing
-rmfilter_mkdev [--all] glob
-    Removes the given glob pattern from the list of access violation filters for mkdev sandboxing
+addfilter_mkbdev glob
+    Adds the given glob pattern to the list of access violation filters for mkbdev sandboxing
+rmfilter_mkbdev [--all] glob
+    Removes the given glob pattern from the list of access violation filters for mkbdev sandboxing
+addfilter_mkcdev glob
+    Adds the given glob pattern to the list of access violation filters for mkcdev sandboxing
+rmfilter_mkcdev [--all] glob
+    Removes the given glob pattern from the list of access violation filters for mkcdev sandboxing
 addfilter_mkfifo glob
     Adds the given glob pattern to the list of access violation filters for mkfifo sandboxing
 rmfilter_mkfifo [--all] glob
